@@ -3,7 +3,7 @@ from pathlib import Path
 
 from .config import *  # noqa: F403
 
-__version__ = '1.9.4'
+__version__ = '1.9.5'
 
 portable_path = Path(sys.executable).parent / 'is_portable'
 IS_PORTABLE = portable_path.exists()
@@ -13,8 +13,7 @@ IS_PORTABLE = portable_path.exists()
 has_ms_appinfo = False
 try:
     from winrt.windows.applicationmodel import AppInfo
-    _current_appinfo = AppInfo.current()  # type: ignore
-    has_ms_appinfo = True
+    has_ms_appinfo = AppInfo.current is not None
 except Exception:
     pass
 
