@@ -1,20 +1,9 @@
 # This file is part of Gajim.
 #
-# Gajim is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published
-# by the Free Software Foundation; version 3 only.
-#
-# Gajim is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with Gajim. If not, see <http://www.gnu.org/licenses/>.
+# SPDX-License-Identifier: GPL-3.0-only
 
-"""
-Handles Jingle sessions (XEP 0166)
-"""
+
+# Handles Jingle sessions (XEP 0166)
 
 # TODO:
 # * 'senders' attribute of 'content' element
@@ -30,13 +19,13 @@ Handles Jingle sessions (XEP 0166)
 from __future__ import annotations
 
 from typing import Any
-from typing import Callable
-from typing import Optional
 from typing import TYPE_CHECKING
 
-import time
 import logging
-from enum import Enum, unique
+import uuid
+from collections.abc import Callable
+from enum import Enum
+from enum import unique
 
 import nbxmpp
 from nbxmpp import JID
@@ -47,20 +36,24 @@ from nbxmpp.util import generate_id
 from gajim.common import app
 from gajim.common import events
 from gajim.common.client import Client
-from gajim.common.const import KindConstant
-from gajim.common.helpers import AdditionalDataDict
-from gajim.common.jingle_transport import get_jingle_transport
-from gajim.common.jingle_transport import JingleTransportIBB
+from gajim.common.file_props import FilesProp
 from gajim.common.jingle_content import get_jingle_content
 from gajim.common.jingle_content import JingleContent
 from gajim.common.jingle_content import JingleContentSetupException
 from gajim.common.jingle_ft import State
-from gajim.common.file_props import FilesProp
+from gajim.common.jingle_transport import get_jingle_transport
+from gajim.common.jingle_transport import JingleTransportIBB
+from gajim.common.storage.archive import models as mod
+from gajim.common.storage.archive.const import ChatDirection
+from gajim.common.storage.archive.const import MessageState
+from gajim.common.storage.archive.const import MessageType
+from gajim.common.util.datetime import utc_now
+
 if TYPE_CHECKING:
     from gajim.common.jingle_transport import JingleTransport
 
 
-log = logging.getLogger("app.c.jingle_session")
+log = logging.getLogger('app.c.jingle_session')
 
 
 JINGLE_EVENTS = {
@@ -75,54 +68,54 @@ JINGLE_EVENTS = {
 # FIXME: Move it to JingleSession.States?
 @unique
 class JingleStates(Enum):
-    """
+    '''
     States in which jingle session may exist
-    """
+    '''
     ENDED = 0
     PENDING = 1
     ACTIVE = 2
 
 
 class OutOfOrder(Exception):
-    """
+    '''
     Exception that should be raised when an action is received when in the wrong
     state
-    """
+    '''
 
 
 class TieBreak(Exception):
-    """
+    '''
     Exception that should be raised in case of a tie, when we overrule the other
     action
-    """
+    '''
 
 
 class FailedApplication(Exception):
-    """
+    '''
     Exception that should be raised in case responder supports none of the
     payload-types offered by the initiator
-    """
+    '''
 
 
 class JingleSession:
-    """
+    '''
     This represents one jingle session, that is, one or more content types
     negotiated between an initiator and a responder.
-    """
+    '''
 
     def __init__(self,
                  con: Client,
                  weinitiate: bool,
                  jid: str,
-                 iq_id: Optional[str] = None,
-                 sid: Optional[str] = None,
+                 iq_id: str | None = None,
+                 sid: str | None = None,
                  werequest: bool = False
                  ) -> None:
-        """
+        '''
         con -- connection object,
         weinitiate -- boolean, are we the initiator?
         jid - jid of the other entity
-        """
+        '''
         # negotiated contents
         self.contents: dict[tuple[str, str], JingleContent] = {}
         self.connection = con  # connection to use
@@ -156,7 +149,7 @@ class JingleSession:
         # use .prepend() to add new callbacks, especially when you're going
         # to send error instead of ack
         self.callbacks: dict[str, list[Callable[
-            [nbxmpp.Node, nbxmpp.Node, Optional[nbxmpp.Node], str],
+            [nbxmpp.Node, nbxmpp.Node, nbxmpp.Node | None, str],
             None]]] = {
             'content-accept': [self.__ack,
                                self.__on_content_accept,
@@ -194,34 +187,34 @@ class JingleSession:
             self.iq_ids.append(iq_id)
 
     def approve_session(self) -> None:
-        """
+        '''
         Called when user accepts session in UI (when we aren't the initiator)
-        """
+        '''
         self.accept_session()
 
     def decline_session(self) -> None:
-        """
+        '''
         Called when user declines session in UI (when we aren't the initiator)
-        """
+        '''
         reason = nbxmpp.Node('reason')
         reason.addChild('decline')
         self._session_terminate(reason)
 
     def cancel_session(self) -> None:
-        """
+        '''
         Called when user declines session in UI (when we aren't the initiator)
-        """
+        '''
         reason = nbxmpp.Node('reason')
         reason.addChild('cancel')
         self._session_terminate(reason)
 
-    def approve_content(self, media: str, name: Optional[str] = None) -> None:
+    def approve_content(self, media: str, name: str | None = None) -> None:
         content = self.get_content(media, name)
         if content:
             content.accepted = True
             self.on_session_state_changed(content)
 
-    def reject_content(self, media: str, name: Optional[str] = None) -> None:
+    def reject_content(self, media: str, name: str | None = None) -> None:
         content = self.get_content(media, name)
         if content:
             if self.state == JingleStates.ACTIVE:
@@ -230,9 +223,9 @@ class JingleSession:
             self.on_session_state_changed()
 
     def end_session(self) -> None:
-        """
+        '''
         Called when user stops or cancel session in UI
-        """
+        '''
         reason = nbxmpp.Node('reason')
         if self.state == JingleStates.ACTIVE:
             reason.addChild('success')
@@ -241,9 +234,9 @@ class JingleSession:
         self._session_terminate(reason)
 
     def get_content(self,
-                    media: Optional[str] = None,
-                    name: Optional[str] = None
-                    ) -> Optional[JingleContent]:
+                    media: str | None = None,
+                    name: str | None = None
+                    ) -> JingleContent | None:
         if media is None:
             return None
         for content in self.contents.values():
@@ -257,12 +250,12 @@ class JingleSession:
                     content: JingleContent,
                     creator: str = 'we'
                     ) -> None:
-        """
+        '''
         Add new content to session. If the session is active, this will send
         proper stanza to update session
 
         Creator must be one of ('we', 'peer', 'initiator', 'responder')
-        """
+        '''
         assert creator in ('we', 'peer', 'initiator', 'responder')
         if ((creator == 'we' and self.weinitiate) or
                 (creator == 'peer' and not self.weinitiate)):
@@ -280,13 +273,13 @@ class JingleSession:
     def remove_content(self,
                        creator: str,
                        name: str,
-                       reason: Optional[nbxmpp.Node] = None
+                       reason: nbxmpp.Node | None = None
                        ) -> None:
-        """
+        '''
         Remove the content `name` created by `creator`
         by sending content-remove, or by sending session-terminate if
         there is no content left.
-        """
+        '''
         if (creator, name) in self.contents:
             content = self.contents[(creator, name)]
             self.__content_remove(content, reason)
@@ -297,7 +290,7 @@ class JingleSession:
     def modify_content(self,
                        creator: str,
                        name: str,
-                       transport: Optional[JingleTransport] = None
+                       transport: JingleTransport | None = None
                        ) -> None:
         '''
         Currently used for transport replacement
@@ -312,7 +305,7 @@ class JingleSession:
         content.accepted = True
 
     def on_session_state_changed(self,
-                                 content: Optional[JingleContent] = None
+                                 content: JingleContent | None = None
                                  ) -> None:
         if self.state == JingleStates.ENDED:
             # Session not yet started, only one action possible:
@@ -345,23 +338,23 @@ class JingleSession:
                 self.__content_accept(content)
 
     def is_ready(self) -> bool:
-        """
+        '''
         Return True when all codecs and candidates are ready (for all contents)
-        """
+        '''
         ready = [content.is_ready() for content in self.contents.values()]
         return all(ready) and self.accepted
 
     def accept_session(self) -> None:
-        """
+        '''
         Mark the session as accepted
-        """
+        '''
         self.accepted = True
         self.on_session_state_changed()
 
     def start_session(self) -> None:
-        """
+        '''
         Mark the session as ready to be started
-        """
+        '''
         self.accepted = True
         self.on_session_state_changed()
 
@@ -388,11 +381,11 @@ class JingleSession:
         self.connection.connection.send(stanza)
 
     def on_stanza(self, stanza: nbxmpp.Node) -> None:
-        """
+        '''
         A callback for ConnectionJingle. It gets stanza, then tries to send
         it to all internally registered callbacks. First one to raise
         nbxmpp.NodeProcessed breaks function
-        """
+        '''
         jingle = stanza.getTag('jingle')
         error = stanza.getTag('error')
         if error:
@@ -431,12 +424,12 @@ class JingleSession:
     def __ack(self,
               stanza: nbxmpp.Node,
               jingle: nbxmpp.Node,
-              error: Optional[nbxmpp.Node],
+              error: nbxmpp.Node | None,
               action: str
               ) -> None:
-        """
+        '''
         Default callback for action stanzas -- simple ack and stop processing
-        """
+        '''
         response = stanza.buildReply('result')
         response.delChild(response.getQuery())
         self.connection.connection.send(response)
@@ -475,7 +468,7 @@ class JingleSession:
     def __on_transport_replace(self,
                                stanza: nbxmpp.Node,
                                jingle: nbxmpp.Node,
-                               error: Optional[nbxmpp.Node],
+                               error: nbxmpp.Node | None,
                                action: str
                                ) -> None:
         for content in jingle.iterTags('content'):
@@ -518,7 +511,7 @@ class JingleSession:
     def __on_session_info(self,
                           stanza: nbxmpp.Node,
                           jingle: nbxmpp.Node,
-                          error: Optional[nbxmpp.Node],
+                          error: nbxmpp.Node | None,
                           action: str
                           ) -> None:
         # TODO: active, (un)hold, (un)mute
@@ -549,7 +542,7 @@ class JingleSession:
     def __on_content_remove(self,
                             stanza: nbxmpp.Node,
                             jingle: nbxmpp.Node,
-                            error: Optional[nbxmpp.Node],
+                            error: nbxmpp.Node | None,
                             action: str
                             ) -> None:
         for content in jingle.iterTags('content'):
@@ -570,7 +563,7 @@ class JingleSession:
     def __on_session_accept(self,
                             stanza: nbxmpp.Node,
                             jingle: nbxmpp.Node,
-                            error: Optional[nbxmpp.Node],
+                            error: nbxmpp.Node | None,
                             action: str
                             ) -> None:
         # FIXME
@@ -581,13 +574,13 @@ class JingleSession:
     @staticmethod
     def __on_content_accept(stanza: nbxmpp.Node,
                             jingle: nbxmpp.Node,
-                            error: Optional[nbxmpp.Node],
+                            error: nbxmpp.Node | None,
                             action: str
                             ) -> None:
-        """
+        '''
         Called when we get content-accept stanza or equivalent one (like
         session-accept)
-        """
+        '''
         # check which contents are accepted
         # for content in jingle.iterTags('content'):
         #     creator = content['creator']
@@ -597,7 +590,7 @@ class JingleSession:
     def __on_content_add(self,
                          stanza: nbxmpp.Node,
                          jingle: nbxmpp.Node,
-                         error: Optional[nbxmpp.Node],
+                         error: nbxmpp.Node | None,
                          action: str
                          ) -> None:
         if self.state == JingleStates.ENDED:
@@ -615,13 +608,13 @@ class JingleSession:
     def __on_session_initiate(self,
                               stanza: nbxmpp.Node,
                               jingle: nbxmpp.Node,
-                              error: Optional[nbxmpp.Node],
+                              error: nbxmpp.Node | None,
                               action: str
                               ) -> None:
-        """
+        '''
         We got a jingle session request from other entity, therefore we are the
         receiver... Unpack the data, inform the user
-        """
+        '''
         if self.state != JingleStates.ENDED:
             raise OutOfOrder
 
@@ -699,25 +692,35 @@ class JingleSession:
 
         account = self.connection.name
         jid = JID.from_string(self.peerjid)
-        timestamp = time.time()
-        additional_data = AdditionalDataDict()
-        additional_data.set_value('gajim', 'sid', self.sid)
-        app.storage.archive.insert_into_logs(
-            account,
-            jid.bare,
-            timestamp,
-            KindConstant.CALL_INCOMING,
-            additional_data=additional_data)
+
+        call_data = mod.Call(
+            sid=self.sid,
+            state=0,  # TODO
+        )
+
+        message = mod.Message(
+            account_=account,
+            remote_jid_=jid.new_as_bare(),
+            resource=None,
+            type=MessageType.CHAT,
+            direction=ChatDirection.INCOMING,
+            timestamp=utc_now(),
+            state=MessageState.ACKNOWLEDGED,
+            id=str(uuid.uuid4()),
+            call=call_data,
+        )
+
+        app.storage.archive.insert_object(message)
 
     def __broadcast(self,
                     stanza: nbxmpp.Node,
                     jingle: nbxmpp.Node,
-                    error: Optional[nbxmpp.Node],
+                    error: nbxmpp.Node | None,
                     action: str
                     ) -> None:
-        """
+        '''
         Broadcast the stanza contents to proper content handlers
-        """
+        '''
         # if jingle is None: # it is a iq-result stanza
         #    for cn in self.contents.values():
         #        cn.on_stanza(stanza, None, error, action)
@@ -731,8 +734,7 @@ class JingleSession:
             name = content['name']
             creator = content['creator']
             if (creator, name) not in self.contents:
-                text = 'Content %s (created by %s) does not exist' % (name,
-                                                                      creator)
+                text = f'Content {name} (created by {creator}) does not exist'
                 self.__send_error(stanza,
                                   'bad-request',
                                   text=text,
@@ -745,7 +747,7 @@ class JingleSession:
     def __on_session_terminate(self,
                                stanza: nbxmpp.Node,
                                jingle: nbxmpp.Node,
-                               error: Optional[nbxmpp.Node],
+                               error: nbxmpp.Node | None,
                                action: str
                                ) -> None:
         self.connection.get_module('Jingle').delete_jingle_session(self.sid)
@@ -753,7 +755,7 @@ class JingleSession:
         if reason not in ('success', 'cancel', 'decline'):
             self.__dispatch_error(reason, text)
         if text:
-            text = '%s (%s)' % (reason, text)
+            text = f'{reason} ({text})'
         else:
             # TODO
             text = reason
@@ -773,12 +775,12 @@ class JingleSession:
     def __broadcast_all(self,
                         stanza: nbxmpp.Node,
                         jingle: nbxmpp.Node,
-                        error: Optional[nbxmpp.Node],
+                        error: nbxmpp.Node | None,
                         action: str
                         ) -> None:
-        """
+        '''
         Broadcast the stanza to all content handlers
-        """
+        '''
         for content in self.contents.values():
             content.on_stanza(stanza, None, error, action)
 
@@ -787,7 +789,7 @@ class JingleSession:
                          ) -> tuple[
                              list[JingleContent],
                              list[tuple[str, str]],
-                             Optional[str]]:
+                             str | None]:
         # TODO: Needs some reworking
         contents: list[JingleContent] = []
         contents_rejected: list[tuple[str, str]] = []
@@ -823,12 +825,12 @@ class JingleSession:
         return (contents, contents_rejected, failure_reason)
 
     def __dispatch_error(self,
-                         error: Optional[str] = None,
-                         text: Optional[str] = None,
-                         type_: Optional[str] = None
+                         error: str | None = None,
+                         text: str | None = None,
+                         type_: str | None = None
                          ) -> None:
         if text:
-            text = '%s (%s)' % (error, text)
+            text = '{error} ({text})'
         if type_ != 'modify':
             self._raise_event('jingle-error-received', reason=text or error)
 
@@ -855,7 +857,7 @@ class JingleSession:
 
     def __make_jingle(self,
                       action: str,
-                      reason: Optional[nbxmpp.Node] = None
+                      reason: nbxmpp.Node | None = None
                       ) -> tuple[Iq, nbxmpp.Node]:
         stanza = nbxmpp.Iq(typ='set', to=nbxmpp.JID.from_string(self.peerjid),
                            frm=self.ourjid)
@@ -872,12 +874,12 @@ class JingleSession:
 
     def __send_error(self,
                      stanza: nbxmpp.Node,
-                     error: Optional[str],
-                     jingle_error: Optional[str] = None,
-                     text: Optional[str] = None,
-                     type_: Optional[str] = None
+                     error: str | None,
+                     jingle_error: str | None = None,
+                     text: str | None = None,
+                     type_: str | None = None
                      ) -> None:
-        err_stanza = nbxmpp.Error(stanza, '%s %s' % (Namespace.STANZAS, error))
+        err_stanza = nbxmpp.Error(stanza, f'{Namespace.STANZAS} {error}')
         err = err_stanza.getTag('error')
         if type_:
             err.setAttr('type', type_)
@@ -890,18 +892,18 @@ class JingleSession:
 
     @staticmethod
     def __append_content(jingle: nbxmpp.Node, content: JingleContent) -> None:
-        """
+        '''
         Append <content/> element to <jingle/> element
-        """
+        '''
         jingle.addChild('content',
                         attrs={'name': content.name,
                                'creator': content.creator,
                                'senders': content.senders})
 
     def __append_contents(self, jingle: nbxmpp.Node) -> None:
-        """
+        '''
         Append all <content/> elements to <jingle/>
-        """
+        '''
         # TODO: integrate with __appendContent?
         # TODO: parameters 'name', 'content'?
         for content in self.contents.values():
@@ -926,7 +928,7 @@ class JingleSession:
         self.collect_iq_id(stanza.getID())
         self.state = JingleStates.ACTIVE
 
-    def __session_info(self, payload: Optional[nbxmpp.Node] = None) -> None:
+    def __session_info(self, payload: nbxmpp.Node | None = None) -> None:
         assert self.state != JingleStates.ENDED
         stanza, jingle = self.__make_jingle('session-info')
         if payload:
@@ -940,7 +942,7 @@ class JingleSession:
         # it isn't being called explicitly.
         self.__session_info(payload)
 
-    def _session_terminate(self, reason: Optional[nbxmpp.Node] = None) -> None:
+    def _session_terminate(self, reason: nbxmpp.Node | None = None) -> None:
         stanza, jingle = self.__make_jingle('session-terminate', reason=reason)
         self.__broadcast_all(stanza, jingle, None, 'session-terminate-sent')
         if self.connection.connection and self.connection.state.is_available:
@@ -988,7 +990,7 @@ class JingleSession:
 
     def __content_remove(self,
                          content: JingleContent,
-                         reason: Optional[nbxmpp.Node] = None
+                         reason: nbxmpp.Node | None = None
                          ) -> None:
         assert self.state != JingleStates.ENDED
         if self.connection.connection and self.connection.state.is_available:
