@@ -1,30 +1,20 @@
 # This file is part of Gajim.
 #
-# Gajim is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published
-# by the Free Software Foundation; version 3 only.
-#
-# Gajim is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with Gajim. If not, see <http://www.gnu.org/licenses/>.
+# SPDX-License-Identifier: GPL-3.0-only
+
+
+# Handles Jingle Transports (currently only ICE-UDP)
 
-"""
-Handles Jingle Transports (currently only ICE-UDP)
-"""
 
 from __future__ import annotations
 
 from typing import Any
-from typing import Optional
 
 import logging
 import socket
 import uuid
-from enum import IntEnum, unique
+from enum import IntEnum
+from enum import unique
 
 import nbxmpp
 from nbxmpp.namespaces import Namespace
@@ -53,18 +43,18 @@ def get_jingle_transport(node: nbxmpp.Node):
 
 @unique
 class TransportType(IntEnum):
-    """
+    '''
     Possible types of a JingleTransport
-    """
+    '''
     ICEUDP = 1
     SOCKS5 = 2
     IBB = 3
 
 
 class JingleTransport:
-    """
+    '''
     An abstraction of a transport in Jingle sessions
-    """
+    '''
 
     __slots__ = ['type_', 'candidates', 'remote_candidates', 'connection',
                  'file_props', 'ourjid', 'sid']
@@ -74,27 +64,27 @@ class JingleTransport:
         self.candidates: list[dict[str, Any]] = []
         self.remote_candidates: list[dict[str, Any]] = []
 
-        self.connection: Optional[Client] = None
-        self.file_props: Optional[FileProp] = None
-        self.ourjid: Optional[str] = None
-        self.sid: Optional[str] = None
+        self.connection: Client | None = None
+        self.file_props: FileProp | None = None
+        self.ourjid: str | None = None
+        self.sid: str | None = None
 
     def _iter_candidates(self):
         for candidate in self.candidates:
             yield self.make_candidate(candidate)
 
     def make_candidate(self, candidate: dict[str, Any]) -> Any:
-        """
+        '''
         Build a candidate stanza for the given candidate
-        """
+        '''
 
     def make_transport(self,
-                       candidates: Optional[list[dict[str, Any]]] = None
+                       candidates: list[dict[str, Any]] | None = None
                        ) -> nbxmpp.Node:
-        """
+        '''
         Build a transport stanza with the given candidates (or self.candidates
         if candidates is None)
-        """
+        '''
         if not candidates:
             candidates = list(self._iter_candidates())
         else:
@@ -104,9 +94,9 @@ class JingleTransport:
         return transport
 
     def parse_transport_stanza(self, transport: nbxmpp.Node) -> list[Any]:
-        """
+        '''
         Return the list of transport candidates from a transport stanza
-        """
+        '''
         return []
 
     def set_connection(self, conn: Client) -> None:
@@ -125,15 +115,15 @@ class JingleTransport:
 
 
 class JingleTransportSocks5(JingleTransport):
-    """
+    '''
     Socks5 transport in jingle scenario
     Note: Don't forget to call set_file_props after initialization
-    """
-    def __init__(self, node: Optional[nbxmpp.Node] = None) -> None:
+    '''
+    def __init__(self, node: nbxmpp.Node | None = None) -> None:
         JingleTransport.__init__(self, TransportType.SOCKS5)
         self.connection = None
         self.remote_candidates: list[dict[str, Any]] = []
-        self.sid: Optional[str] = None
+        self.sid: str | None = None
         if node and node.getAttr('sid'):
             self.sid = node.getAttr('sid')
 
@@ -151,7 +141,7 @@ class JingleTransportSocks5(JingleTransport):
         return nbxmpp.Node('candidate', attrs=attrs)
 
     def make_transport(self,
-                       candidates: Optional[list[dict[str, Any]]] = None,
+                       candidates: list[dict[str, Any]] | None = None,
                        add_candidates: bool = True
                        ) -> nbxmpp.Node:
         if add_candidates:
@@ -210,7 +200,7 @@ class JingleTransportSocks5(JingleTransport):
         type_preference = 126
         priority = (2**16) * type_preference
 
-        hosts: set[Optional[str]] = set()
+        hosts: set[str | None] = set()
         local_ip_cand: list[dict[str, Any]] = []
 
         my_ip = self.connection.local_address
@@ -250,7 +240,10 @@ class JingleTransportSocks5(JingleTransport):
             pass  # ignore address-related errors for getaddrinfo
 
         try:
-            from netifaces import interfaces, ifaddresses, AF_INET, AF_INET6
+            from netifaces import AF_INET
+            from netifaces import AF_INET6
+            from netifaces import ifaddresses
+            from netifaces import interfaces
             for ifaceName in interfaces():
                 addresses = ifaddresses(ifaceName)
                 if AF_INET in addresses:
@@ -349,7 +342,7 @@ class JingleTransportSocks5(JingleTransport):
 
         self._add_candidates(proxy_cand)
 
-    def get_content(self) -> Optional[JingleContent]:
+    def get_content(self) -> JingleContent | None:
         sesn = self.connection.get_module('Jingle').get_jingle_session(
             self.ourjid, self.file_props.sid)
         for content in sesn.contents.values():
@@ -368,7 +361,7 @@ class JingleTransportSocks5(JingleTransport):
             return
 
         iq = nbxmpp.Iq(to=proxy['jid'], frm=self.ourjid, typ='set')
-        auth_id = "au_" + proxy['sid']
+        auth_id = 'au_' + proxy['sid']
         iq.setID(auth_id)
         query = iq.setTag('query', namespace=Namespace.BYTESTREAM)
         query.setAttr('sid', proxy['sid'])
@@ -407,8 +400,8 @@ class JingleTransportSocks5(JingleTransport):
 class JingleTransportIBB(JingleTransport):
 
     def __init__(self,
-                 node: Optional[nbxmpp.Node] = None,
-                 block_sz: Optional[str] = None
+                 node: nbxmpp.Node | None = None,
+                 block_sz: str | None = None
                  ) -> None:
 
         JingleTransport.__init__(self, TransportType.IBB)
@@ -419,7 +412,7 @@ class JingleTransportIBB(JingleTransport):
             self.block_sz = '4096'
 
         self.connection = None
-        self.sid: Optional[str] = None
+        self.sid: str | None = None
         if node and node.getAttr('sid'):
             self.sid = node.getAttr('sid')
 
@@ -432,7 +425,7 @@ class JingleTransportIBB(JingleTransport):
 
 
 class JingleTransportICEUDP(JingleTransport):
-    def __init__(self, node: Optional[nbxmpp.Node]) -> None:
+    def __init__(self, node: nbxmpp.Node | None) -> None:
         JingleTransport.__init__(self, TransportType.ICEUDP)
 
     def make_candidate(self, candidate) -> nbxmpp.Node:
@@ -463,7 +456,7 @@ class JingleTransportICEUDP(JingleTransport):
         return nbxmpp.Node('candidate', attrs=attrs)
 
     def make_transport(self,
-                       candidates: Optional[list[dict[str, Any]]] = None
+                       candidates: list[dict[str, Any]] | None = None
                        ) -> nbxmpp.Node:
         transport = JingleTransport.make_transport(self, candidates)
         transport.setNamespace(Namespace.JINGLE_ICE_UDP)
