@@ -1,16 +1,6 @@
 # This file is part of Gajim.
 #
-# Gajim is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published
-# by the Free Software Foundation; version 3 only.
-#
-# Gajim is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with Gajim.  If not, see <http://www.gnu.org/licenses/>.
+# SPDX-License-Identifier: GPL-3.0-only
 
 # XEP-0048: Bookmarks
 
@@ -179,9 +169,10 @@ class Bookmarks(BaseModule):
         # If another client creates a MUC, the MUC is locked until the
         # configuration is finished. Give the user some time to finish
         # the configuration.
-        timeout_id = GLib.timeout_add_seconds(
-            10, self._join_with_timeout, bookmarks)
-        self._join_timeouts.append(timeout_id)
+        if app.settings.get_account_setting(self._account, 'autojoin_sync'):
+            timeout_id = GLib.timeout_add_seconds(
+                10, self._join_with_timeout, bookmarks)
+            self._join_timeouts.append(timeout_id)
 
         # TODO: leave mucs
         # leave = [jid for jid, autojoin in changed if not autojoin]
@@ -227,7 +218,8 @@ class Bookmarks(BaseModule):
 
         self._cleanup_bookmarks(bookmarks)
         self._bookmarks = self._convert_to_dict(bookmarks)
-        self.auto_join_bookmarks(self.bookmarks)
+        if app.settings.get_account_setting(self._account, 'autojoin_sync'):
+            self.auto_join_bookmarks(self.bookmarks)
         app.ged.raise_event(
             BookmarksReceived(account=self._account))
 
@@ -279,6 +271,8 @@ class Bookmarks(BaseModule):
         self.store_bookmarks([new_bookmark])
 
     def add_or_modify(self, jid: JID, **kwargs: Any) -> None:
+        if not app.settings.get_account_setting(self._account, 'autojoin_sync'):
+            kwargs.pop('autojoin', None)
         bookmark = self._bookmarks.get(jid)
         if bookmark is not None:
             self.modify(jid, **kwargs)
@@ -314,4 +308,5 @@ class Bookmarks(BaseModule):
             GLib.source_remove(_id)
 
     def cleanup(self) -> None:
+        BaseModule.cleanup(self)
         self._remove_timeouts()
