@@ -1,20 +1,15 @@
 # This file is part of Gajim.
 #
-# Gajim is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published
-# by the Free Software Foundation; version 3 only.
-#
-# Gajim is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with Gajim.  If not, see <http://www.gnu.org/licenses/>.
+# SPDX-License-Identifier: GPL-3.0-only
 
 # XEP-0202: Entity Time
 
+from __future__ import annotations
+
+from nbxmpp.protocol import JID
+
 from gajim.common import app
+from gajim.common import types
 from gajim.common.modules.base import BaseModule
 
 
@@ -27,12 +22,12 @@ class EntityTime(BaseModule):
         'disable',
     ]
 
-    def __init__(self, con):
+    def __init__(self, con: types.Client) -> None:
         BaseModule.__init__(self, con)
 
         self.handlers = []
 
-    def set_enabled(self, enabled):
+    def set_enabled(self, enabled: bool) -> None:
         if not enabled:
             self._nbxmpp('EntityTime').disable()
             return
@@ -44,7 +39,7 @@ class EntityTime(BaseModule):
         self._nbxmpp('EntityTime').enable()
         self._nbxmpp('EntityTime').set_allow_reply_func(self._allow_reply)
 
-    def _allow_reply(self, jid):
+    def _allow_reply(self, jid: JID) -> bool:
         item = self._con.get_module('Roster').get_item(jid.bare)
         if item is None:
             return False
