@@ -1,32 +1,20 @@
 # This file is part of Gajim.
 #
-# Gajim is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published
-# by the Free Software Foundation; version 3 only.
-#
-# Gajim is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with Gajim.  If not, see <http://www.gnu.org/licenses/>.
+# SPDX-License-Identifier: GPL-3.0-only
 
 # XEP-0313: Message Archive Management
 
 from __future__ import annotations
 
-from typing import Any
-from typing import Optional
-
-import time
 from datetime import datetime
 from datetime import timedelta
+from datetime import timezone
 
 import nbxmpp
-from nbxmpp.errors import StanzaError
-from nbxmpp.errors import MalformedStanzaError
 from nbxmpp.errors import is_error
+from nbxmpp.errors import MalformedStanzaError
+from nbxmpp.errors import StanzaError
+from nbxmpp.modules.util import raise_if_error
 from nbxmpp.namespaces import Namespace
 from nbxmpp.protocol import JID
 from nbxmpp.protocol import Message
@@ -36,25 +24,19 @@ from nbxmpp.structs import StanzaHandler
 from nbxmpp.structs import StanzaIDData
 from nbxmpp.task import Task
 from nbxmpp.util import generate_id
-from nbxmpp.modules.util import raise_if_error
 
 from gajim.common import app
 from gajim.common import types
+from gajim.common.const import ArchiveState
+from gajim.common.const import ClientState
+from gajim.common.const import SyncThreshold
 from gajim.common.events import ArchivingIntervalFinished
 from gajim.common.events import FeatureDiscovered
-from gajim.common.events import MamMessageReceived
-from gajim.common.events import MessageUpdated
 from gajim.common.events import RawMamMessageReceived
-from gajim.common.const import ArchiveState, ClientState
-from gajim.common.const import KindConstant
-from gajim.common.const import SyncThreshold
-from gajim.common.helpers import AdditionalDataDict
-from gajim.common.helpers import get_retraction_text
-from gajim.common.modules.misc import parse_oob
-from gajim.common.modules.misc import parse_correction
-from gajim.common.modules.util import get_eme_message
-from gajim.common.modules.util import as_task
 from gajim.common.modules.base import BaseModule
+from gajim.common.modules.util import as_task
+from gajim.common.storage.archive import models as mod
+from gajim.common.util.datetime import FIRST_UTC_DATETIME
 
 
 class MAM(BaseModule):
@@ -72,10 +54,10 @@ class MAM(BaseModule):
         self.handlers = [
             StanzaHandler(name='message',
                           callback=self._set_message_archive_info,
-                          priority=41),
+                          priority=42),
             StanzaHandler(name='message',
                           callback=self._mam_message_received,
-                          priority=51),
+                          priority=41),
         ]
 
         self.available = False
@@ -133,29 +115,10 @@ class MAM(BaseModule):
 
         return properties.mam.archive.bare_match(expected_archive)
 
-    def _get_unique_id(self,
-                       properties: MessageProperties
-                       ) -> tuple[Optional[str], Optional[str]]:
-        if properties.type.is_groupchat:
-            return properties.mam.id, None
-
-        if properties.is_self_message:
-            return None, properties.id
-
-        if properties.is_muc_pm:
-            return properties.mam.id, properties.id
-
-        if self._con.get_own_jid().bare_match(properties.from_):
-            # message we sent
-            return properties.mam.id, properties.id
-
-        # A message we received
-        return properties.mam.id, None
-
     @staticmethod
     def _get_stanza_id(properties: MessageProperties,
                        archive_jid: str
-                       ) -> Optional[StanzaIDData]:
+                       ) -> StanzaIDData | None:
         for stanza_id in properties.stanza_ids:
             if stanza_id.by == archive_jid:
                 return stanza_id
@@ -202,16 +165,24 @@ class MAM(BaseModule):
         if not self.is_catch_up_finished(archive_jid):
             return
 
-        app.storage.archive.set_archive_infos(
-            archive_jid,
-            last_mam_id=stanza_id.id,
-            last_muc_timestamp=timestamp)
+        if timestamp is not None:
+            timestamp = datetime.fromtimestamp(timestamp, timezone.utc)
+
+        app.storage.archive.upsert_row(
+            mod.MAMArchiveState(
+                account_=self._account,
+                remote_jid_=JID.from_string(archive_jid),
+                to_stanza_id=stanza_id.id,
+                to_stanza_ts=timestamp,
+            )
+        )
 
     def _mam_message_received(self,
                               _con: types.xmppClient,
                               stanza: Message,
                               properties: MessageProperties
                               ) -> None:
+
         if not properties.is_mam_message:
             return
 
@@ -230,114 +201,19 @@ class MAM(BaseModule):
         if not self._is_valid_request(properties):
             self._log.warning('Invalid MAM Message: unknown query id %s',
                               properties.mam.query_id)
-            self._log.debug(stanza)
+            self._log.warning(stanza)
             raise nbxmpp.NodeProcessed
 
-        is_groupchat = properties.type.is_groupchat
-        if is_groupchat:
-            kind = KindConstant.GC_MSG
-        else:
-            if properties.from_.bare_match(self._con.get_own_jid()):
-                kind = KindConstant.CHAT_MSG_SENT
-            else:
-                kind = KindConstant.CHAT_MSG_RECV
-
-        stanza_id, message_id = self._get_unique_id(properties)
-
-        # Search for duplicates
-        if app.storage.archive.find_stanza_id(self._account,
-                                              str(properties.mam.archive),
-                                              stanza_id,
-                                              message_id,
-                                              groupchat=is_groupchat):
-            self._log.info('Found duplicate with stanza-id: %s, '
-                           'message-id: %s', stanza_id, message_id)
+        stanza_id = properties.mam.id
+        if stanza_id is None:
+            self._log.warning('Unable to determine stanza id')
+            self._log.warning(stanza)
             raise nbxmpp.NodeProcessed
 
-        additional_data = AdditionalDataDict()
-        if properties.has_user_delay:
-            # Record it as a user timestamp
-            additional_data.set_value(
-                'gajim', 'user_timestamp', properties.user_timestamp)
-
-        parse_oob(properties, additional_data)
-
-        msgtxt = properties.body
-
-        if properties.is_encrypted:
-            additional_data['encrypted'] = properties.encrypted.additional_data
-        else:
-            if properties.eme is not None:
-                msgtxt = get_eme_message(properties.eme)
-
-        if properties.is_moderation:
-            additional_data.set_value(
-                'retracted', 'by', properties.moderation.moderator_jid)
-            additional_data.set_value(
-                'retracted', 'timestamp', properties.moderation.timestamp)
-            additional_data.set_value(
-                'retracted', 'reason', properties.moderation.reason)
-
-            msgtxt = get_retraction_text(
-                self._account,
-                properties.moderation.moderator_jid,
-                properties.moderation.reason)
-
-        if not msgtxt:
-            # For example Chatstates, Receipts, Chatmarkers
-            self._log.debug(stanza.getProperties())
-            return
-
-        jid = properties.jid.new_as_bare()
-        if properties.is_muc_pm:
-            jid = properties.jid
-
-        if properties.is_self_message:
-            # Self messages can only be deduped with origin-id
-            if message_id is None:
-                self._log.warning('Self message without origin-id found')
-                return
-            stanza_id = message_id
-
-        event_attr: dict[str, Any] = {
-            'account': self._account,
-            'jid': jid,
-            'msgtxt': properties.body,
-            'properties': properties,
-            'additional_data': additional_data,
-            'unique_id': properties.id,
-            'stanza_id': stanza_id,
-            'archive_jid': properties.mam.archive,
-            'kind': kind,
-        }
-
-        correct_id = parse_correction(properties)
-        if correct_id is not None:
-            app.ged.raise_event(MessageUpdated(account=self._account,
-                                               jid=jid,
-                                               msgtxt=properties.body,
-                                               properties=properties,
-                                               correct_id=correct_id))
-            app.storage.archive.store_message_correction(
-                self._account,
-                jid,
-                correct_id,
-                properties.body,
-                properties.type.is_groupchat)
-            return
-
-        app.storage.archive.insert_into_logs(
-            self._account,
-            jid,
-            properties.mam.timestamp,
-            kind,
-            message=msgtxt,
-            contact_name=properties.muc_nickname,
-            additional_data=additional_data,
-            stanza_id=stanza_id,
-            message_id=properties.id)
-
-        app.ged.raise_event(MamMessageReceived(**event_attr))
+        if app.storage.archive.check_if_stanza_id_exists(
+            self._account, properties.remote_jid, stanza_id):
+            self._log.info('Received duplicated message from MAM: %s', stanza_id)
+            raise nbxmpp.NodeProcessed
 
     def _is_valid_request(self, properties: MessageProperties) -> bool:
         valid_id = self._mam_query_ids.get(properties.mam.archive, None)
@@ -348,13 +224,14 @@ class MAM(BaseModule):
         self._mam_query_ids[jid] = query_id
         return query_id
 
-    def _get_query_params(self) -> tuple[Optional[ſtr], Optional[datetime]]:
+    def _get_query_params(self) -> tuple[str | None, datetime | None]:
         own_jid = self._con.get_own_jid().bare
-        archive = app.storage.archive.get_archive_infos(own_jid)
+        archive = app.storage.archive.get_mam_archive_state(
+            self._account, own_jid)
 
         mam_id = None
         if archive is not None:
-            mam_id = archive.last_mam_id
+            mam_id = archive.to_stanza_id
 
         start_date = None
         if mam_id:
@@ -363,7 +240,7 @@ class MAM(BaseModule):
 
         else:
             # First Start, we request the last week
-            start_date = datetime.utcnow() - timedelta(days=7)
+            start_date = datetime.now(timezone.utc) - timedelta(days=7)
             self._log.info('Request archive: %s, after date %s',
                            own_jid, start_date)
         return mam_id, start_date
@@ -371,51 +248,52 @@ class MAM(BaseModule):
     def _get_muc_query_params(self,
                               jid: JID,
                               threshold: SyncThreshold
-                              ) -> tuple[Optional[str], Optional[datetime]]:
-        archive = app.storage.archive.get_archive_infos(jid)
+                              ) -> tuple[str | None, datetime | None]:
+
+        archive = app.storage.archive.get_mam_archive_state(self._account, jid)
         mam_id = None
         start_date = None
+        now = datetime.now(timezone.utc)
 
-        if archive is None or archive.last_mam_id is None:
+        if archive is None or archive.to_stanza_id is None:
             # First join
-            start_date = datetime.utcnow() - timedelta(days=1)
+            start_date = now - timedelta(days=1)
             self._log.info('Request archive: %s, after date %s',
                            jid, start_date)
 
         elif threshold == SyncThreshold.NO_THRESHOLD:
             # Not our first join and no threshold set
 
-            mam_id = archive.last_mam_id
+            mam_id = archive.to_stanza_id
             self._log.info('Request archive: %s, after mam-id %s',
-                           jid, archive.last_mam_id)
+                           jid, archive.to_stanza_id)
 
         else:
             # Not our first join, check how much time elapsed since our
             # last join and check against threshold
-            last_timestamp = archive.last_muc_timestamp
-            if last_timestamp is None:
+            last = archive.to_stanza_ts
+            if last is None:
                 self._log.info('No last muc timestamp found: %s', jid)
-                last_timestamp = 0
+                last = FIRST_UTC_DATETIME
 
-            last = datetime.utcfromtimestamp(float(last_timestamp))
-            if datetime.utcnow() - last > timedelta(days=threshold):
+            if now - last > timedelta(days=threshold):
                 # To much time has elapsed since last join, apply threshold
-                start_date = datetime.utcnow() - timedelta(days=threshold)
+                start_date = now - timedelta(days=threshold)
                 self._log.info('Too much time elapsed since last join, '
                                'request archive: %s, after date %s, '
                                'threshold: %s', jid, start_date, threshold)
 
             else:
                 # Request from last mam-id
-                mam_id = archive.last_mam_id
+                mam_id = archive.to_stanza_id
                 self._log.info('Request archive: %s, after mam-id %s:',
-                               jid, archive.last_mam_id)
+                               jid, archive.to_stanza_id)
 
         return mam_id, start_date
 
     @as_task
     def request_archive_on_signin(self):
-        _task = yield
+        _task = yield  # noqa: F841
 
         own_jid = self._con.get_own_jid().bare
 
@@ -431,7 +309,10 @@ class MAM(BaseModule):
                 self._log.warning(result)
                 return
 
-            app.storage.archive.reset_archive_infos(result.jid)
+            self._log.warning(result)
+            self._log.warning('Reset archive state: %s', own_jid)
+            app.storage.archive.reset_mam_archive_state(
+                self._account, result.jid)
             _, start_date = self._get_query_params()
             result = yield self._execute_query(result.jid, None, start_date)
             if is_error(result):
@@ -442,24 +323,30 @@ class MAM(BaseModule):
             # <last> is not provided if the requested page was empty
             # so this means we did not get anything hence we only need
             # to update the archive info if <last> is present
-            app.storage.archive.set_archive_infos(
-                result.jid,
-                last_mam_id=result.rsm.last,
-                last_muc_timestamp=time.time())
+            app.storage.archive.upsert_row(
+                mod.MAMArchiveState(
+                    account_=self._account,
+                    remote_jid_=result.jid,
+                    to_stanza_id=result.rsm.last,
+                    to_stanza_ts=datetime.now(timezone.utc),
+                )
+            )
 
         if start_date is not None:
             # Record the earliest timestamp we request from
             # the account archive. For the account archive we only
             # set start_date at the very first request.
-            app.storage.archive.set_archive_infos(
-                result.jid,
-                oldest_mam_timestamp=start_date.timestamp())
+            app.storage.archive.upsert_row(
+                mod.MAMArchiveState(
+                    account_=self._account,
+                    remote_jid_=result.jid,
+                    from_stanza_ts=start_date
+                )
+            )
 
     @as_task
-    def request_archive_on_muc_join(self,
-                                    jid: JID
-                                    ):
-        _task = yield
+    def request_archive_on_muc_join(self, jid: JID):
+        _task = yield  # noqa: F841
 
         threshold = app.settings.get_group_chat_setting(self._account,
                                                         jid,
@@ -469,37 +356,51 @@ class MAM(BaseModule):
         if threshold == SyncThreshold.NO_SYNC:
             return
 
+        contact = self._get_contact(jid, groupchat=True)
+        contact.notify('mam-sync-started')
+
         mam_id, start_date = self._get_muc_query_params(jid, threshold)
 
         result = yield self._execute_query(jid, mam_id, start_date)
         if is_error(result):
             if result.condition != 'item-not-found':
                 self._log.warning(result)
+                contact.notify('mam-sync-error', result.get_text())
                 return
 
-            app.storage.archive.reset_archive_infos(result.jid)
+            self._log.warning(result)
+            self._log.warning('Reset archive state: %s', jid)
+            app.storage.archive.reset_mam_archive_state(
+                self._account, result.jid)
             _, start_date = self._get_muc_query_params(jid, threshold)
             result = yield self._execute_query(result.jid, None, start_date)
             if is_error(result):
                 self._log.warning(result)
+                contact.notify('mam-sync-error', result.get_text())
                 return
 
         if result.rsm.last is not None:
             # <last> is not provided if the requested page was empty
             # so this means we did not get anything hence we only need
             # to update the archive info if <last> is present
-            app.storage.archive.set_archive_infos(
-                result.jid,
-                last_mam_id=result.rsm.last,
-                last_muc_timestamp=time.time())
+            app.storage.archive.upsert_row(
+                mod.MAMArchiveState(
+                    account_=self._account,
+                    remote_jid_=result.jid,
+                    to_stanza_id=result.rsm.last,
+                    to_stanza_ts=datetime.now(timezone.utc)
+                )
+            )
+
+        contact.notify('mam-sync-finished')
 
     @as_task
     def _execute_query(self,
                        jid: JID,
-                       mam_id: Optional[str],
-                       start_date: Optional[datetime]
+                       mam_id: str | None,
+                       start_date: datetime | None
                        ):
-        _task = yield
+        _task = yield  # noqa: F841
 
         if jid in self._catch_up_finished:
             self._catch_up_finished.remove(jid)
@@ -516,8 +417,14 @@ class MAM(BaseModule):
         raise_if_error(result)
 
         while not result.complete:
-            app.storage.archive.set_archive_infos(result.jid,
-                                                  last_mam_id=result.rsm.last)
+            app.storage.archive.upsert_row(
+                mod.MAMArchiveState(
+                    account_=self._account,
+                    remote_jid_=result.jid,
+                    to_stanza_id=result.rsm.last,
+                )
+            )
+
             queryid = self._get_query_id(result.jid)
 
             result = yield self.make_query(result.jid,
@@ -537,8 +444,8 @@ class MAM(BaseModule):
     def request_archive_interval(self,
                                  start_date: datetime,
                                  end_date: datetime,
-                                 after: Optional[str] = None,
-                                 queryid: Optional[str] = None
+                                 after: str | None = None,
+                                 queryid: str | None = None
                                  ) -> str:
 
         jid = self._con.get_own_jid().bare
@@ -574,15 +481,21 @@ class MAM(BaseModule):
         self._remove_query_id(result.jid)
 
         if start_date:
-            timestamp = start_date.timestamp()
+            timestamp = start_date
         else:
             timestamp = ArchiveState.ALL
 
         if result.complete:
             self._log.info('Request finished: %s, last mam id: %s',
                            result.jid, result.rsm.last)
-            app.storage.archive.set_archive_infos(
-                result.jid, oldest_mam_timestamp=timestamp)
+            app.storage.archive.upsert_row(
+                mod.MAMArchiveState(
+                    account_=self._account,
+                    remote_jid_=result.jid,
+                    from_stanza_ts=timestamp,
+                )
+            )
+
             app.ged.raise_event(ArchivingIntervalFinished(
                 account=self._account,
                 query_id=queryid))
