@@ -1,34 +1,28 @@
 # This file is part of Gajim.
 #
-# Gajim is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published
-# by the Free Software Foundation; version 3 only.
-#
-# Gajim is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with Gajim.  If not, see <http://www.gnu.org/licenses/>.
+# SPDX-License-Identifier: GPL-3.0-only
 
 # XEP-0118: User Tune
 
 from __future__ import annotations
 
-from typing import Optional
+from typing import Any
 
 from nbxmpp.namespaces import Namespace
 from nbxmpp.protocol import JID
+from nbxmpp.structs import MessageProperties
 from nbxmpp.structs import TuneData
 
 from gajim.common import app
 from gajim.common import ged
+from gajim.common import types
+from gajim.common.dbus.music_track import MusicTrackListener
+from gajim.common.events import MusicTrackChanged
+from gajim.common.events import SignedIn
 from gajim.common.modules.base import BaseModule
 from gajim.common.modules.util import event_node
 from gajim.common.modules.util import store_publish
-from gajim.common.dbus.music_track import MusicTrackListener
-from gajim.common.helpers import event_filter
+from gajim.common.util.decorators import event_filter
 
 
 class UserTune(BaseModule):
@@ -38,20 +32,24 @@ class UserTune(BaseModule):
         'set_tune',
     ]
 
-    def __init__(self, con):
+    def __init__(self, con: types.Client) -> None:
         BaseModule.__init__(self, con)
         self._register_pubsub_handler(self._tune_received)
-        self._current_tune: Optional[TuneData] = None
+        self._current_tune: TuneData | None = None
         self._contact_tunes: dict[JID, TuneData] = {}
 
-    def get_current_tune(self) -> Optional[TuneData]:
+    def get_current_tune(self) -> TuneData | None:
         return self._current_tune
 
-    def get_contact_tune(self, jid: JID) -> Optional[TuneData]:
+    def get_contact_tune(self, jid: JID) -> TuneData | None:
         return self._contact_tunes.get(jid)
 
     @event_node(Namespace.TUNE)
-    def _tune_received(self, _con, _stanza, properties):
+    def _tune_received(self,
+                       _con: types.xmppClient,
+                       _stanza: Any,
+                       properties: MessageProperties
+                       ) -> None:
         if properties.pubsub_event.retracted:
             return
 
@@ -65,7 +63,7 @@ class UserTune(BaseModule):
         contact.notify('tune-update', data)
 
     @store_publish
-    def set_tune(self, tune, force=False):
+    def set_tune(self, tune: TuneData | None, force: bool = False) -> None:
         if not self._con.get_module('PEP').supported:
             return
 
@@ -81,7 +79,7 @@ class UserTune(BaseModule):
         self._log.info('Send %s', tune)
         self._nbxmpp('Tune').set_tune(tune)
 
-    def set_enabled(self, enable):
+    def set_enabled(self, enable: bool) -> None:
         if enable:
             self.register_events([
                 ('music-track-changed', ged.CORE, self._on_music_track_changed),
@@ -96,10 +94,10 @@ class UserTune(BaseModule):
         self.set_tune(MusicTrackListener.get().current_tune)
 
     @event_filter(['account'])
-    def _on_signed_in(self, _event):
+    def _on_signed_in(self, _event: SignedIn) -> None:
         self._publish_current_tune()
 
-    def _on_music_track_changed(self, event):
+    def _on_music_track_changed(self, event: MusicTrackChanged) -> None:
         if self._current_tune == event.info:
             return
 
