@@ -1,35 +1,24 @@
 # This file is part of Gajim.
 #
-# Gajim is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published
-# by the Free Software Foundation; version 3 only.
-#
-# Gajim is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with Gajim. If not, see <http://www.gnu.org/licenses/>.
+# SPDX-License-Identifier: GPL-3.0-only
 
 from __future__ import annotations
 
-from typing import Union
-from typing import Match
-from typing import Optional
+from typing import Any
 
-import string
 import re
+import string
 from dataclasses import dataclass
 from dataclasses import field
+from re import Match
 
 from gi.repository import GLib
 
 from gajim.common import regex
 from gajim.common.const import URIType
-from gajim.common.helpers import parse_uri as analyze_uri
-from gajim.common.helpers import validate_jid
-from gajim.common.text_helpers import jid_to_iri
+from gajim.common.util.jid import validate_jid
+from gajim.common.util.text import escape_iri_query
+from gajim.common.util.uri import parse_uri as analyze_uri
 
 PRE = '`'
 STRONG = '*'
@@ -37,7 +26,7 @@ STRIKE = '~'
 EMPH = '_'
 
 WHITESPACE = set(string.whitespace)
-SPAN_DIRS = set([PRE, STRONG, STRIKE, EMPH])
+SPAN_DIRS = {PRE, STRONG, STRIKE, EMPH}
 VALID_SPAN_START = WHITESPACE | SPAN_DIRS
 
 PRE_RX = r'(?P<pre>^```.+?(^```$(.|\Z)))'
@@ -73,8 +62,7 @@ class BaseHyperlink(StyleObject):
     def get_markup_string(self) -> str:
         href = GLib.markup_escape_text(self.uri)
         text = GLib.markup_escape_text(self.text)
-        title = '' if href == text else f' title="{href}"'
-        return f'<a href="{href}"{title}>{text}</a>'
+        return f'<a href="{href}">{text}</a>'
 
 
 @dataclass
@@ -82,6 +70,11 @@ class Hyperlink(BaseHyperlink):
     name: str = field(default='uri', init=False)
 
 
+@dataclass
+class Address(BaseHyperlink):
+    name: str = field(default='address', init=False)
+
+
 @dataclass
 class XMPPAddress(BaseHyperlink):
     name: str = field(default='xmppadr', init=False)
@@ -96,7 +89,7 @@ class MailAddress(BaseHyperlink):
 class Block(StyleObject):
 
     @classmethod
-    def from_match(cls, match: Match[str]) -> Block:
+    def from_match(cls: Any, match: Match[str]) -> Block:
         return cls(start=match.start(),
                    end=match.end(),
                    text=match.group(cls.name))
@@ -182,10 +175,10 @@ def find_byte_index(text: str, index: int):
         if index == index_:
             return byte_index
 
-    raise ValueError('index not in string: %s, %s' % (text, index))
+    raise ValueError(f'index not in string: {text}, {index}')
 
 
-def process(text: Union[str, bytes], level: int = 0) -> ParsingResult:
+def process(text: str | bytes, level: int = 0) -> ParsingResult:
     if isinstance(text, bytes):
         text = text.decode()
 
@@ -208,7 +201,7 @@ def process(text: Union[str, bytes], level: int = 0) -> ParsingResult:
     return ParsingResult(text, blocks)
 
 
-def process_uris(text: Union[str, bytes]) -> list[BaseHyperlink]:
+def process_uris(text: str | bytes) -> list[BaseHyperlink]:
     if isinstance(text, bytes):
         text = text.decode()
 
@@ -319,7 +312,7 @@ def _parse_uris(line: str,
                 offset_bytes: int) -> list[BaseHyperlink]:
     uris: list[BaseHyperlink] = []
 
-    def make(start: int, end: int, is_jid: bool) -> Optional[BaseHyperlink]:
+    def make(start: int, end: int, is_jid: bool) -> BaseHyperlink | None:
         if line[end - 1] == ',':
             # Trim one trailing comma
             end -= 1
@@ -394,7 +387,7 @@ def _make_hyperlink(line: str,
                     end: int,
                     offset: int,
                     offset_bytes: int,
-                    is_jid: bool) -> Optional[BaseHyperlink]:
+                    is_jid: bool) -> BaseHyperlink | None:
 
     text = line[start:end + 1]
 
@@ -406,12 +399,12 @@ def _make_hyperlink(line: str,
 
     uri = text
     if is_jid:
-        cls_ = XMPPAddress
+        cls_ = Address
         try:
             validate_jid(text)
         except ValueError:
             return None
-        uri = jid_to_iri(text)
+        uri = 'about:ambiguous-address?' + escape_iri_query(text)
 
     else:
         uri = text
