@@ -1,22 +1,11 @@
 # This file is part of Gajim.
 #
-# Gajim is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published
-# by the Free Software Foundation; version 3 only.
-#
-# Gajim is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with Gajim. If not, see <http://www.gnu.org/licenses/>.
+# SPDX-License-Identifier: GPL-3.0-only
 
 from __future__ import annotations
 
 from typing import Any
 from typing import cast
-from typing import Optional
 
 import locale
 import logging
@@ -26,6 +15,7 @@ from gi.repository import Gdk
 from gi.repository import GObject
 from gi.repository import Gtk
 from gi.repository import Pango
+from nbxmpp.stringprep import saslprep
 
 from gajim.common import app
 from gajim.common import passwords
@@ -33,21 +23,22 @@ from gajim.common import types
 from gajim.common.const import ClientState
 from gajim.common.i18n import _
 from gajim.common.i18n import p_
-from gajim.common.settings import AllSettingsT
+from gajim.common.setting_values import AllSettingsT
 
-from .const import Setting
-from .const import SettingKind
-from .const import SettingType
-from .dialogs import ConfirmationDialog
-from .dialogs import DialogButton
-from .menus import build_accounts_menu
-from .settings import PopoverSetting
-from .settings import SettingsBox
-from .settings import SettingsDialog
-from .util import get_app_window
-from .util import open_window
+from gajim.gtk.const import Setting
+from gajim.gtk.const import SettingKind
+from gajim.gtk.const import SettingType
+from gajim.gtk.dialogs import ConfirmationDialog
+from gajim.gtk.dialogs import DialogButton
+from gajim.gtk.menus import build_accounts_menu
+from gajim.gtk.omemo_trust_manager import OMEMOTrustManager
+from gajim.gtk.settings import PopoverSetting
+from gajim.gtk.settings import SettingsBox
+from gajim.gtk.settings import SettingsDialog
+from gajim.gtk.util import get_app_window
+from gajim.gtk.util import open_window
 
-log = logging.getLogger('gajim.gui.accounts')
+log = logging.getLogger('gajim.gtk.accounts')
 
 
 class AccountsWindow(Gtk.ApplicationWindow):
@@ -167,7 +158,7 @@ class AccountsWindow(Gtk.ApplicationWindow):
         if not initial:
             self._accounts[account].show()
 
-    def select_account(self, account: str, page: Optional[str] = None) -> None:
+    def select_account(self, account: str, page: str | None = None) -> None:
         try:
             self._accounts[account].select(page)
         except KeyError:
@@ -266,6 +257,7 @@ class AccountMenu(Gtk.Box):
             back_row.emit('activate')
         self._accounts_listbox.remove(row)
         sub_menu = self._stack.get_child_by_name(f'{row.account}-menu')
+        assert sub_menu is not None
         self._stack.remove(sub_menu)
         row.destroy()
         sub_menu.destroy()
@@ -325,6 +317,7 @@ class AccountSubMenu(Gtk.ListBox):
         self.add(BackMenuItem())
         self.add(PageMenuItem('general', _('General')))
         self.add(PageMenuItem('privacy', _('Privacy')))
+        self.add(PageMenuItem('encryption-omemo', _('Encryption (OMEMO)')))
         self.add(PageMenuItem('connection', _('Connection')))
         self.add(PageMenuItem('advanced', _('Advanced')))
         self.add(RemoveMenuItem())
@@ -424,13 +417,15 @@ class PageMenuItem(MenuItem):
         super().__init__(name)
 
         if name == 'general':
-            icon = 'preferences-system-symbolic'
+            icon = 'avatar-default-symbolic'
         elif name == 'privacy':
             icon = 'preferences-system-privacy-symbolic'
+        elif name == 'encryption-omemo':
+            icon = 'channel-secure-symbolic'
         elif name == 'connection':
             icon = 'preferences-system-network-symbolic'
         elif name == 'advanced':
-            icon = 'preferences-other-symbolic'
+            icon = 'preferences-system-symbolic'
         else:
             icon = 'dialog-error-symbolic'
 
@@ -452,14 +447,15 @@ class Account:
         self._settings = settings
 
         self._settings.add_page(GeneralPage(account))
-        self._settings.add_page(ConnectionPage(account))
         self._settings.add_page(PrivacyPage(account))
+        self._settings.add_page(EncryptionOMEMOPage(account))
+        self._settings.add_page(ConnectionPage(account))
         self._settings.add_page(AdvancedPage(account))
 
         self._account_row = AccountRow(account)
         self._menu.add_account(self._account_row)
 
-    def select(self, page_name: Optional[str] = None) -> None:
+    def select(self, page_name: str | None = None) -> None:
         self._account_row.emit('activate')
         if page_name is not None:
             self._menu.set_page(self._account, page_name)
@@ -614,13 +610,10 @@ class AddNewAccountPage(Gtk.Box):
         self.set_vexpand(True)
         self.set_hexpand(True)
         self.set_margin_top(24)
-        pixbuf = Gtk.IconTheme.load_icon_for_scale(
-            Gtk.IconTheme.get_default(),
-            'org.gajim.Gajim-symbolic',
-            100,
-            self.get_scale_factor(),
-            Gtk.IconLookupFlags.FORCE_SIZE)
-        self.add(Gtk.Image.new_from_pixbuf(pixbuf))
+        image = Gtk.Image.new_from_icon_name(
+            'gajim-symbolic', Gtk.IconSize.from_name('100'))
+        image.set_opacity(0.2)
+        self.add(image)
 
         button = Gtk.Button(label=_('Add Account'))
         button.get_style_context().add_class('suggested-action')
@@ -637,6 +630,7 @@ class GenericSettingPage(Gtk.Box):
         Gtk.Box.__init__(self, orientation=Gtk.Orientation.VERTICAL, spacing=12)
         self.set_valign(Gtk.Align.START)
         self.set_vexpand(True)
+        self.get_style_context().add_class('settings-page')
         self.account = account
 
         self.listbox = SettingsBox(account)
@@ -719,7 +713,7 @@ class GeneralPage(GenericSettingPage):
                     _('Global Status'),
                     SettingType.ACCOUNT_CONFIG,
                     'sync_with_global_status',
-                    desc=_('Synchronise the status of all accounts')),
+                    desc=_('Synchronize the status of all accounts')),
 
             Setting(SettingKind.SWITCH,
                     _('Remember Last Status'),
@@ -755,7 +749,7 @@ class PrivacyPage(GenericSettingPage):
 
     def __init__(self, account: str) -> None:
         self._account = account
-        self._client: Optional[types.Client] = None
+        self._client: types.Client | None = None
         if app.account_is_connected(account):
             self._client = app.get_client(account)
 
@@ -771,12 +765,27 @@ class PrivacyPage(GenericSettingPage):
         }
 
         chatstate_entries = {
-            'all': _('Enabled'),
-            'composing_only': _('Composing Only'),
             'disabled': _('Disabled'),
+            'composing_only': _('Composing Only'),
+            'all': _('All Chat States'),
+        }
+
+        encryption_entries = {
+            '': _('Unencrypted'),
+            'OMEMO': 'OMEMO',
+            'OpenPGP': 'OpenPGP',
+            'PGP': 'PGP',
         }
 
         settings = [
+            Setting(SettingKind.POPOVER,
+                    _('Default Encryption'),
+                    SettingType.ACCOUNT_CONFIG,
+                    'encryption_default',
+                    desc=_('Encryption method to use '
+                           'unless overridden on a per-contact basis'),
+                    props={'entries': encryption_entries}),
+
             Setting(SettingKind.SWITCH,
                     _('Idle Time'),
                     SettingType.ACCOUNT_CONFIG,
@@ -913,6 +922,39 @@ class PrivacyPage(GenericSettingPage):
             'send_marker', None, context='private')
 
 
+class EncryptionOMEMOPage(GenericSettingPage):
+
+    name = 'encryption-omemo'
+
+    def __init__(self, account: str) -> None:
+        settings = [
+            Setting(SettingKind.SWITCH,
+                    _('Blind Trust'),
+                    SettingType.ACCOUNT_CONFIG,
+                    'omemo_blind_trust',
+                    desc=_('Blindly trust new devices until you verify them'))
+        ]
+        GenericSettingPage.__init__(self, account, settings)
+
+        heading = Gtk.Label(label=_('Trust Management'))
+        heading.get_style_context().add_class('bold')
+        heading.set_xalign(0)
+        self.add(heading)
+
+        btbv_label = Gtk.Label()
+        btbv_label.set_xalign(0)
+        wiki_url = 'https://dev.gajim.org/gajim/gajim/-/wikis/help/OMEMO'
+        link_text = _('Read more about blind trust')
+        markup = f'<a href="{wiki_url}">{link_text}</a>'
+        btbv_label.set_markup(markup)
+        self.add(btbv_label)
+
+        omemo_trust_manager = OMEMOTrustManager(account)
+        omemo_trust_manager.set_margin_top(18)
+        self.pack_end(omemo_trust_manager, True, True, 0)
+        self.reorder_child(omemo_trust_manager, 0)
+
+
 class ConnectionPage(GenericSettingPage):
 
     name = 'connection'
@@ -963,7 +1005,9 @@ class ConnectionPage(GenericSettingPage):
 
     @staticmethod
     def _get_proxies() -> dict[str, str]:
-        return {proxy: proxy for proxy in app.settings.get_proxies()}
+        proxies = {proxy: proxy for proxy in app.settings.get_proxies()}
+        proxies['no-proxy'] = _('No Proxy')
+        return proxies
 
     @staticmethod
     def _on_proxy_edit(*args: Any) -> None:
@@ -1006,7 +1050,12 @@ class AdvancedPage(GenericSettingPage):
                     SettingType.ACCOUNT_CONFIG,
                     'enable_security_labels',
                     desc=_('Show labels describing confidentiality of '
-                           'messages, if the server supports XEP-0258'))
+                           'messages, if the server supports XEP-0258')),
+            Setting(SettingKind.SWITCH,
+                    _('Synchronize joined group chats'),
+                    SettingType.ACCOUNT_CONFIG,
+                    'autojoin_sync',
+                    desc=_('Synchronize joined group chats with other devices.')),
         ]
         GenericSettingPage.__init__(self, account, settings)
 
@@ -1016,9 +1065,9 @@ class PriorityDialog(SettingsDialog):
 
         neg_priority = app.settings.get('enable_negative_priority')
         if neg_priority:
-            range_ = (-128, 127)
+            range_ = (-128, 127, 1)
         else:
-            range_ = (0, 127)
+            range_ = (0, 127, 1)
 
         settings = [
             Setting(SettingKind.SWITCH,
@@ -1072,7 +1121,7 @@ class CutstomHostnameDialog(SettingsDialog):
                     SettingType.ACCOUNT_CONFIG,
                     'custom_port',
                     bind='account::use_custom_host',
-                    props={'range_': (0, 65535)},),
+                    props={'range_': (0, 65535, 1)}),
 
             Setting(SettingKind.COMBO,
                     _('Type'),
@@ -1141,6 +1190,12 @@ class LoginDialog(SettingsDialog):
         self.connect('destroy', self.on_destroy)
 
     def on_password_change(self, new_password: str, _data: Any) -> None:
+        try:
+            new_password = saslprep(new_password)
+        except Exception:
+            # TODO: Show warning for invalid passwords
+            return
+
         passwords.save_password(self.account, new_password)
 
     def on_destroy(self, *args: Any) -> None:
