@@ -1,63 +1,50 @@
 # This file is part of Gajim.
 #
-# Gajim is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published
-# by the Free Software Foundation; version 3 only.
-#
-# Gajim is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with Gajim. If not, see <http://www.gnu.org/licenses/>.
+# SPDX-License-Identifier: GPL-3.0-only
 
 from __future__ import annotations
 
 from typing import Any
 from typing import cast
-from typing import Optional
-from typing import Union
 
 import logging
 
 from gi.repository import Gtk
-
 from nbxmpp import JID
 from nbxmpp import Namespace
+from nbxmpp.errors import BaseError
 from nbxmpp.errors import is_error
 from nbxmpp.errors import StanzaError
 from nbxmpp.structs import DiscoInfo
 
 from gajim.common import app
 from gajim.common import types
-from gajim.common.helpers import get_subscription_request_msg
-from gajim.common.helpers import validate_jid
 from gajim.common.i18n import _
 from gajim.common.modules.util import as_task
+from gajim.common.util.jid import validate_jid
+from gajim.common.util.user_strings import get_subscription_request_msg
 
-from .assistant import Assistant
-from .assistant import Page
-from .assistant import ErrorPage
-from .assistant import ProgressPage
-from .groupchat_info import GroupChatInfoScrolled
-from .builder import get_builder
-from .util import open_window
+from gajim.gtk.assistant import Assistant
+from gajim.gtk.assistant import ErrorPage
+from gajim.gtk.assistant import Page
+from gajim.gtk.builder import get_builder
+from gajim.gtk.groupchat_info import GroupChatInfoScrolled
+from gajim.gtk.util import open_window
 
-log = logging.getLogger('gajim.gui.add_contact')
+log = logging.getLogger('gajim.gtk.add_contact')
 
 
 class AddContact(Assistant):
     def __init__(self,
-                 account: Optional[str] = None,
-                 jid: Optional[JID] = None,
-                 nick: Optional[str] = None):
+                 account: str | None = None,
+                 jid: JID | None = None,
+                 nick: str | None = None):
         Assistant.__init__(self)
         self.account = account
         self.jid = jid
         self._nick = nick
 
-        self._result: Union[DiscoInfo, StanzaError, None] = None
+        self._result: DiscoInfo | StanzaError | None = None
 
         self.add_button('next', _('Next'), complete=True,
                         css_class='suggested-action')
@@ -75,7 +62,7 @@ class AddContact(Assistant):
             'gateway': Gateway(),
         })
 
-        progress = cast(ProgressPage, self.add_default_page('progress'))
+        progress = self.add_default_page('progress')
         progress.set_title(_('Gathering information…'))
         progress.set_text(_('Trying to gather information on this address…'))
 
@@ -141,13 +128,15 @@ class AddContact(Assistant):
 
     @as_task
     def _disco_info(self, account: str, address: str) -> Any:
-        _task = yield
+        _task = yield  # noqa: F841
 
         client = app.get_client(account)
 
-        result = yield client.get_module('Discovery').disco_info(address)
+        result = yield client.get_module('Discovery').disco_info(
+            address,
+            timeout=10)
         if is_error(result):
-            assert isinstance(result, StanzaError)
+            assert isinstance(result, BaseError)
             self._process_error(account, result)
             raise result
 
@@ -155,7 +144,11 @@ class AddContact(Assistant):
         assert isinstance(result, DiscoInfo)
         self._process_info(account, result)
 
-    def _process_error(self, account: str, result: StanzaError) -> None:
+    def _process_error(self,
+                       account: str,
+                       result: BaseError
+                       ) -> None:
+
         log.debug('Error received: %s', result)
         self._result = result
 
@@ -163,12 +156,14 @@ class AddContact(Assistant):
             'service-unavailable',  # Prosody
             'subscription-required'  # ejabberd
         ]
-        if result.condition in contact_conditions:
+        if (isinstance(self._result, StanzaError) and
+                result.condition in contact_conditions):
             # It seems to be a contact
             address_page = cast(Contact, self.get_page('contact'))
             address_page.prepare(account, result)
             self.show_page('contact', Gtk.StackTransitionType.SLIDE_LEFT)
         else:
+            # TimeoutStanzaError is handled here
             error_page = cast(ErrorPage, self.get_page('error'))
             error_page.set_text(result.get_text())
             self.show_page('error', Gtk.StackTransitionType.SLIDE_LEFT)
@@ -214,7 +209,7 @@ class AddContact(Assistant):
 
 
 class Address(Page):
-    def __init__(self, account: Optional[str], jid: Optional[JID]) -> None:
+    def __init__(self, account: str | None, jid: JID | None) -> None:
         Page.__init__(self)
         self.title = _('Add Contact')
 
@@ -342,9 +337,9 @@ class Contact(Page):
         Page.__init__(self)
         self.title = _('Add Contact')
 
-        self._result: Union[DiscoInfo, StanzaError, None] = None
-        self._account: Optional[str] = None
-        self._contact: Optional[types.BareContact] = None
+        self._result: DiscoInfo | BaseError | None = None
+        self._account: str | None = None
+        self._contact: types.BareContact | None = None
 
         self._ui = get_builder('add_contact.ui')
         self.add(self._ui.contact_grid)
@@ -359,7 +354,7 @@ class Contact(Page):
     def get_default_button(self) -> str:
         return 'add'
 
-    def prepare(self, account: str, result: Union[DiscoInfo, StanzaError]):
+    def prepare(self, account: str, result: DiscoInfo | StanzaError):
         self._result = result
         self._account = account
 
@@ -382,7 +377,7 @@ class Contact(Page):
         open_window(
             'ContactInfo', account=self._account, contact=self._contact)
 
-    def get_subscription_data(self) -> dict[str, Union[str, list[str], bool]]:
+    def get_subscription_data(self) -> dict[str, str | list[str] | bool]:
         group = self._ui.group_combo.get_child().get_text()
         groups = [group] if group else []
         return {
@@ -397,8 +392,8 @@ class Gateway(Page):
         Page.__init__(self)
         self.title = _('Service Gateway')
 
-        self._account: Optional[str] = None
-        self._result: Optional[DiscoInfo] = None
+        self._account: str | None = None
+        self._result: DiscoInfo | None = None
 
         self._ui = get_builder('add_contact.ui')
         self.add(self._ui.gateway_box)
@@ -476,8 +471,9 @@ class Gateway(Page):
 
     def _on_command_clicked(self, _button: Gtk.Button) -> None:
         assert self._result is not None
-        open_window(
-            'AdHocCommands', account=self._account, jid=str(self._result.jid))
+        open_window('AdHocCommands',
+                    account=self._account,
+                    jids=[str(self._result.jid)])
 
 
 class GroupChat(Page):
@@ -485,7 +481,7 @@ class GroupChat(Page):
         Page.__init__(self)
         self.title = _('Join Group Chat?')
 
-        self._result: Optional[DiscoInfo] = None
+        self._result: DiscoInfo | None = None
 
         heading = Gtk.Label(label=_('Join Group Chat?'))
         heading.get_style_context().add_class('large-header')
