@@ -45,6 +45,9 @@ DEFAULT_WORKSPACE_COLOR = 'rgb(191,15,167)'
 # Drag and drop target type URI list (for dropped files)
 TARGET_TYPE_URI_LIST = 80
 
+DND_TARGET_URI_LIST = 'text/uri-list'
+DND_TARGET_FLATPAK = 'application/vnd.portal.filetransfer'
+
 MAX_MESSAGE_LENGTH = 5000
 
 
@@ -158,6 +161,7 @@ WINDOW_MODULES = {
     'PluginsWindow': 'gajim.gtk.plugins',
     'Preferences': 'gajim.gtk.preferences',
     'ProfileWindow': 'gajim.gtk.profile',
+    'QuitDialog': 'gajim.gtk.dialogs',
     'RemoveAccount': 'gajim.gtk.remove_account',
     'RosterItemExchange': 'gajim.gtk.roster_item_exchange',
     'ServerInfo': 'gajim.gtk.server_info',
