@@ -1,25 +1,18 @@
 # This file is part of Gajim.
 #
-# Gajim is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published
-# by the Free Software Foundation; version 3 only.
-#
-# Gajim is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with Gajim. If not, see <http://www.gnu.org/licenses/>.
+# SPDX-License-Identifier: GPL-3.0-only
 
 from __future__ import annotations
 
+import typing
+
 from gi.repository import Gtk
 
 try:
     from gi.repository import Gst
 except Exception:
-    pass
+    if typing.TYPE_CHECKING:
+        from gi.repository import Gst
 
 
 def create_gtk_widget() -> tuple[Gst.Element, Gtk.Widget, str] | None:
