@@ -1,21 +1,10 @@
 # This file is part of Gajim.
 #
-# Gajim is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published
-# by the Free Software Foundation; version 3 only.
-#
-# Gajim is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with Gajim. If not, see <http://www.gnu.org/licenses/>.
+# SPDX-License-Identifier: GPL-3.0-only
 
 from __future__ import annotations
 
 from typing import Any
-from typing import Optional
 
 from gi.repository import Gtk
 
@@ -24,15 +13,15 @@ from gajim.common import events
 from gajim.common import ged
 from gajim.common.client import Client
 from gajim.common.const import SimpleClientState
-from gajim.common.helpers import get_global_status_message
-from gajim.common.helpers import to_one_line
 from gajim.common.i18n import _
+from gajim.common.util.status import get_global_status_message
+from gajim.common.util.text import to_one_line
 
-from .util import EventHelper
+from gajim.gtk.util import EventHelper
 
 
 class StatusMessageSelector(Gtk.Box, EventHelper):
-    def __init__(self, account: Optional[str] = None) -> None:
+    def __init__(self, account: str | None = None) -> None:
         Gtk.Box.__init__(self)
         EventHelper.__init__(self)
         self.get_style_context().add_class('linked')
