@@ -2,25 +2,13 @@
 #
 # This file is part of Gajim.
 #
-# Gajim is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published
-# by the Free Software Foundation; version 3 only.
-#
-# Gajim is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with Gajim. If not, see <http://www.gnu.org/licenses/>.
+# SPDX-License-Identifier: GPL-3.0-only
 
 from __future__ import annotations
 
 from typing import Any
 from typing import cast
 from typing import NamedTuple
-from typing import Optional
-from typing import Union
 
 from enum import IntEnum
 
@@ -57,10 +45,6 @@ CSS_STYLE_OPTIONS: list[StyleOption] = [
                 '.gajim-conversation-text',
                 StyleAttr.COLOR),
 
-    StyleOption(_('Conversation: URL Color'),
-                '.gajim-url',
-                StyleAttr.COLOR),
-
     StyleOption(_('Conversation: Nickname Color (Incoming)'),
                 '.gajim-incoming-nickname',
                 StyleAttr.COLOR),
@@ -81,10 +65,6 @@ CSS_STYLE_OPTIONS: list[StyleOption] = [
                 '.gajim-status-message',
                 StyleAttr.FONT),
 
-    StyleOption(_('Message Correction: Background Color'),
-                '.gajim-msg-correcting text',
-                StyleAttr.BACKGROUND),
-
     StyleOption(_('Chat Banner: Foreground Color'),
                 '.gajim-banner',
                 StyleAttr.COLOR),
@@ -301,7 +281,7 @@ class Themes(Gtk.ApplicationWindow):
 
     @staticmethod
     def _update_preferences_window() -> None:
-        window = cast(Optional[Preferences], get_app_window('Preferences'))
+        window = cast(Preferences | None, get_app_window('Preferences'))
         if window is not None:
             window.update_theme_list()
 
@@ -353,7 +333,7 @@ class Themes(Gtk.ApplicationWindow):
 class Option(Gtk.ListBoxRow):
     def __init__(self,
                  option: StyleOption,
-                 value: Union[str, Pango.FontDescription, None]
+                 value: str | Pango.FontDescription | None
                  ) -> None:
         Gtk.ListBoxRow.__init__(self)
         self.option = option
@@ -382,7 +362,7 @@ class Option(Gtk.ListBoxRow):
         self.add(self._box)
         self.show_all()
 
-    def _init_color(self, color: Optional[str]) -> None:
+    def _init_color(self, color: str | None) -> None:
         color_button = Gtk.ColorButton()
         if color is not None:
             rgba = Gdk.RGBA()
@@ -392,7 +372,7 @@ class Option(Gtk.ListBoxRow):
         color_button.connect('color-set', self._on_color_set)
         self._box.add(color_button)
 
-    def _init_font(self, desc: Optional[Pango.FontDescription]) -> None:
+    def _init_font(self, desc: Pango.FontDescription | None) -> None:
         font_button = Gtk.FontButton()
         if desc is not None:
             font_button.set_font_desc(desc)
